@@ -28,6 +28,8 @@ cp -P ${PWD}/libnvfm.so   ${LIB_LOC}
 cp ${PWD}/nv-fabricmanager  /usr/bin
 cp ${PWD}/nvswitch-audit  /usr/bin
 cp ${PWD}/nvidia-fabricmanager.service  /lib/systemd/system
+cp ${PWD}/nvidia-fabricmanager-start.sh /usr/bin
+chmod +x /usr/bin/nvidia-fabricmanager-start.sh
 
 mkdir /usr/share/nvidia  > /dev/null 2>&1
 mkdir /usr/share/nvidia/nvswitch/  > /dev/null 2>&1
@@ -36,6 +38,7 @@ cp ${PWD}/dgxa100_hgxa100_topology    /usr/share/nvidia/nvswitch/
 cp ${PWD}/dgxh100_hgxh100_topology    /usr/share/nvidia/nvswitch/
 cp ${PWD}/dgxh800_hgxh800_topology    /usr/share/nvidia/nvswitch/
 cp ${PWD}/fabricmanager.cfg           /usr/share/nvidia/nvswitch/
+cp ${PWD}/fabricmanager_multinode.cfg /usr/share/nvidia/nvswitch/
 cp ${PWD}/nv_fm_agent.h               /usr/include
 cp ${PWD}/nv_fm_types.h               /usr/include
 
@@ -49,9 +52,8 @@ cp ${PWD}/dgxgh200_hgxgh200_32gpus_topology /usr/share/nvidia/nvswitch/
 cp ${PWD}/dgxgh200_hgxgh200_32gpus_trunk_connections.csv /usr/share/nvidia/nvswitch/
 cp ${PWD}/dgxgh200_hgxgh200_32gpus_osfp_connections.csv /usr/share/nvidia/nvswitch/
 cp ${PWD}/dgxgh200_hgxgh200_32gpus_osfp_cable_connections.csv /usr/share/nvidia/nvswitch/
-cp ${PWD}/oberon_gh_32gpus_topology /usr/share/nvidia/nvswitch/
-cp ${PWD}/nv_fm_nvl_agent.h     /usr/include
-cp ${PWD}/nv_fm_nvl_types.h     /usr/include
+cp ${PWD}/gh200_nvlink_32gpus_topology /usr/share/nvidia/nvswitch/
+cp ${PWD}/gb200_nvl36r1_c2g4_topology /usr/share/nvidia/nvswitch/
 
 mkdir /usr/share/doc/nvidia-fabricmanager > /dev/null 2>&1
 cp ${PWD}/LICENSE  /usr/share/doc/nvidia-fabricmanager
